/*

The default modifiers matchers assigned to every day. These values are passed to
the `defaultModifiers` prop in DayPicker.tsx.

*/
import { isAfter, isBefore, isSameDay, isSameMonth } from 'date-fns';
/** Determines if a day is outside the displayed month.  */
function isOutside(day, displayMonth) {
    return !isSameMonth(day, displayMonth);
}
/** Determines if a day, when displayed in a month, is interactive.  */
function isInteractive(day, displayMonth, props) {
    /** Props that will make the day button interactive. */
    var interactiveProps = [
        'onSelect',
        'onDayClick',
        'onDayMouseEnter',
        'onDayTouchStart'
    ];
    var toDate = props.toDate, fromDate = props.fromDate, originalProps = props.originalProps;
    var outside = isOutside(day, displayMonth);
    if (props.mode !== 'uncontrolled' && !outside) {
        return true;
    }
    // Uncontrolled mode: if some of the _original props_ passed to the component
    // are not an "interactive" prop, we can assume the day is not interactive.
    if (interactiveProps.every(function (name) { return !(name in originalProps); })) {
        return false;
    }
    // The day is NOT interactive if not in the range specified in the `fromDate`
    // and `toDate` (these values are set also by `fromDay/toDay` and
    // `fromYear/toYear` in the main component.)
    var isAfterToDate = toDate && isAfter(day, toDate);
    var isBeforeFromDate = fromDate && isBefore(day, fromDate);
    var interactive = !isAfterToDate && !isBeforeFromDate && !outside;
    return interactive;
}
/** Determines if a day is "today". */
function isToday(day, _, props) {
    // User can change the "today" date from props, thus we cannot rely to the
    // date now. The today props defaults to `new Date()` anyway...
    return isSameDay(day, props.today);
}
export var defaultModifiers = {
    interactive: isInteractive,
    outside: isOutside,
    today: isToday
};
//# sourceMappingURL=defaultModifiers.js.map