import * as React from 'react';
import { isSameYear, setMonth, startOfMonth } from 'date-fns';
import { useDayPicker } from '../../hooks';
import { UIElement } from '../../types';
/**
 * Render the dropdown to navigate between months.
 */
export function MonthsDropdown(props) {
    var displayMonth = props.displayMonth;
    var _a = useDayPicker(), locale = _a.locale, onMonthChange = _a.onMonthChange, fromDate = _a.fromDate, toDate = _a.toDate, classNames = _a.classNames, styles = _a.styles, Dropdown = _a.components.Dropdown, formatMonthCaption = _a.formatters.formatMonthCaption;
    var dropdownMonths = [];
    if (fromDate && toDate) {
        if (isSameYear(fromDate, toDate)) {
            // only display the months included in the range
            for (var month = fromDate.getMonth(); month <= toDate.getMonth(); month++) {
                dropdownMonths.push(setMonth(startOfMonth(fromDate), month));
            }
        }
        else {
            // display all the 12 months
            for (var month = 0; month <= 11; month++) {
                var anyDate = new Date(); // any date is OK, we just need the year
                dropdownMonths.push(setMonth(startOfMonth(anyDate), month));
            }
        }
    }
    var handleChange = function (e) {
        var newMonth = new Date(displayMonth);
        newMonth.setMonth(Number(e.target.value));
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(newMonth, e);
    };
    return (React.createElement(Dropdown, { className: classNames[UIElement.DropdownMonth], style: styles === null || styles === void 0 ? void 0 : styles[UIElement.DropdownMonth], onChange: handleChange, value: displayMonth.getMonth(), caption: formatMonthCaption(displayMonth, { locale: locale }) }, dropdownMonths.map(function (m) { return (React.createElement("option", { key: m.getMonth(), value: m.getMonth() }, formatMonthCaption(m, { locale: locale }))); })));
}
//# sourceMappingURL=MonthsDropdown.js.map